==> estateplat-common-1.2.3-20180115.084831-14-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtHtbafwdj.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;

/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description 合同备案房屋登记表(第八章)
 */
@Table(name = "fcjy_xjspf_mmht_htbafwdj")
public class FcjyXjspfMmhtHtbafwdj {
    @Id
    private String djid;//主键
    private String htid;//合同ID
    private String djbaqtyd;//登记备案其他约定
    private Integer ygdjqx;//预告登记期限（日）
    private String ygdjqtyd;//预告登记其他约定
    private Integer fwzyqx;//房屋转移期限（日）
    private String fwzyfs;//房屋转移方式
    private Double fwzyjflx;//房屋转移给付利息（百分之）
    private Double fwzywyj;//房屋转移违约金（万分之）
    private String clfs2;//处理方式2
    private String sftyblyg;//是否同意办理预告

    public String getDjid() {
        return djid;
    }

    public void setDjid(String djid) {
        this.djid = djid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getDjbaqtyd() {
        return djbaqtyd;
    }

    public void setDjbaqtyd(String djbaqtyd) {
        this.djbaqtyd = djbaqtyd;
    }

    public Integer getYgdjqx() {
        return ygdjqx;
    }

    public void setYgdjqx(Integer ygdjqx) {
        this.ygdjqx = ygdjqx;
    }

    public String getYgdjqtyd() {
        return ygdjqtyd;
    }

    public void setYgdjqtyd(String ygdjqtyd) {
        this.ygdjqtyd = ygdjqtyd;
    }

    public Integer getFwzyqx() {
        return fwzyqx;
    }

    public void setFwzyqx(Integer fwzyqx) {
        this.fwzyqx = fwzyqx;
    }

    public String getFwzyfs() {
        return fwzyfs;
    }

    public void setFwzyfs(String fwzyfs) {
        this.fwzyfs = fwzyfs;
    }

    public Double getFwzyjflx() {
        return fwzyjflx;
    }

    public void setFwzyjflx(Double fwzyjflx) {
        this.fwzyjflx = fwzyjflx;
    }

    public Double getFwzywyj() {
        return fwzywyj;
    }

    public void setFwzywyj(Double fwzywyj) {
        this.fwzywyj = fwzywyj;
    }

    public String getClfs2() {
        return clfs2;
    }

    public void setClfs2(String clfs2) {
        this.clfs2 = clfs2;
    }

    public String getSftyblyg() {
        return sftyblyg;
    }

    public void setSftyblyg(String sftyblyg) {
        this.sftyblyg = sftyblyg;
    }
}

==> estateplat-common-1.2.3-20180612.132311-117-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtHtbafwdj.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description 合同备案房屋登记表(第八章)
 */
@Table(name = "fcjy_xjspf_mmht_htbafwdj")
public class FcjyXjspfMmhtHtbafwdj implements Serializable {
    @Id
    private String djid;//主键
    private String htid;//合同ID
    private String djbaqtyd;//登记备案其他约定
    private Integer ygdjqx;//预告登记期限（日）
    private String ygdjqtyd;//预告登记其他约定
    private Integer fwzyqx;//房屋转移期限（日）
    private String fwzyfs;//房屋转移方式
    private Double fwzyjflx;//房屋转移给付利息（百分之）
    private Double fwzywyj;//房屋转移违约金（万分之）
    private String clfs2;//处理方式2
    private String sftyblyg;//是否同意办理预告

    public String getDjid() {
        return djid;
    }

    public void setDjid(String djid) {
        this.djid = djid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getDjbaqtyd() {
        return djbaqtyd;
    }

    public void setDjbaqtyd(String djbaqtyd) {
        this.djbaqtyd = djbaqtyd;
    }

    public Integer getYgdjqx() {
        return ygdjqx;
    }

    public void setYgdjqx(Integer ygdjqx) {
        this.ygdjqx = ygdjqx;
    }

    public String getYgdjqtyd() {
        return ygdjqtyd;
    }

    public void setYgdjqtyd(String ygdjqtyd) {
        this.ygdjqtyd = ygdjqtyd;
    }

    public Integer getFwzyqx() {
        return fwzyqx;
    }

    public void setFwzyqx(Integer fwzyqx) {
        this.fwzyqx = fwzyqx;
    }

    public String getFwzyfs() {
        return fwzyfs;
    }

    public void setFwzyfs(String fwzyfs) {
        this.fwzyfs = fwzyfs;
    }

    public Double getFwzyjflx() {
        return fwzyjflx;
    }

    public void setFwzyjflx(Double fwzyjflx) {
        this.fwzyjflx = fwzyjflx;
    }

    public Double getFwzywyj() {
        return fwzywyj;
    }

    public void setFwzywyj(Double fwzywyj) {
        this.fwzywyj = fwzywyj;
    }

    public String getClfs2() {
        return clfs2;
    }

    public void setClfs2(String clfs2) {
        this.clfs2 = clfs2;
    }

    public String getSftyblyg() {
        return sftyblyg;
    }

    public void setSftyblyg(String sftyblyg) {
        this.sftyblyg = sftyblyg;
    }
}
